@@ -58,6 +58,8 @@ class ArtellaMenusManager(menus.MenusManager, object):
 
         menus_config = tpDcc.ConfigsMgr().get_config(
             config_name='artellapipe-menu',
+            package_name=project.get_clean_name(),
+            root_package_name='artellapipe',
             environment=project.get_environment()
         )
         if not menus_config:
@@ -74,7 +76,7 @@ class ArtellaMenusManager(menus.MenusManager, object):
                         if isinstance(i, string_types) and i == 'separator':
                             main_menu.addSeparator()
                             continue
-                        self._menu_creator(main_menu, i, package_name, dev=project.is_dev())
+                        self._menu_creator(main_menu, i, project.get_clean_name(), dev=project.is_dev())
 
         # Tools Menus
         tools_menu_data = self.get_tools_menus() or dict()
@@ -84,7 +86,7 @@ class ArtellaMenusManager(menus.MenusManager, object):
                     if isinstance(i, string_types) and i == 'separator':
                         main_menu.addSeparator()
                         continue
-                    self._menu_creator(main_menu, i, pkg_name, dev=project.is_dev())
+                    self._menu_creator(main_menu, i, project.get_clean_name(), dev=project.is_dev())
 
         self.create_tray_menu(project=project)
         self.create_bug_tracker_action(package_name=package_name)
@@ -94,7 +96,8 @@ class ArtellaMenusManager(menus.MenusManager, object):
     def remove_previous_menus(self, project, package_name=None):
         super(ArtellaMenusManager, self).remove_previous_menus(package_name=package_name)
 
-        parent_menu_bar = qtutils.get_window_menu_bar(tpDcc.Dcc.get_main_window())
+        main_win = tpDcc.Dcc.get_main_window()
+        parent_menu_bar = main_win.menuBar()
         if not parent_menu_bar:
             return
 
@@ -110,7 +113,8 @@ class ArtellaMenusManager(menus.MenusManager, object):
         :return:
         """
 
-        parent_menu_bar = qtutils.get_window_menu_bar(tpDcc.Dcc.get_main_window())
+        main_win = tpDcc.Dcc.get_main_window()
+        parent_menu_bar = main_win.menuBar()
         if not parent_menu_bar:
             return
 
@@ -133,7 +137,8 @@ class ArtellaMenusManager(menus.MenusManager, object):
         :return:
         """
 
-        parent_menu_bar = qtutils.get_window_menu_bar(tpDcc.Dcc.get_main_window())
+        main_win = tpDcc.Dcc.get_main_window()
+        parent_menu_bar = main_win.menuBar()
         if not parent_menu_bar:
             return
 
@@ -156,7 +161,8 @@ class ArtellaMenusManager(menus.MenusManager, object):
         :return:
         """
 
-        parent_menu_bar = qtutils.get_window_menu_bar(tpDcc.Dcc.get_main_window())
+        main_win = tpDcc.Dcc.get_main_window()
+        parent_menu_bar = main_win.menuBar()
         if not parent_menu_bar:
             return
 
